parse_module_import_head

Function parse_module_import_head 

pub fn parse_module_import_head(line: &str) -> Option<ModuleImportHead<'_>>
Parse the leading import token of a single Perl source line.

Returns None when the line does not start with use or require (after leading whitespace) or when no token is present after the keyword.