Module path

Module path 

Filesystem path derivation and normalization for modules. Perl module name/path conversion helpers.

Provides a small, focused API for converting between canonical Perl module names (e.g., Foo::Bar) and module file paths (e.g., Foo/Bar.pm).

Functions

file_path_to_module_name
Convert a filesystem source path into a likely module name.
module_name_to_path
Convert a module name into a relative Perl module path.
module_path_to_name
Convert a module path/key into a module name.
normalize_package_separator
Normalize legacy package separator ' to canonical ::.