resolve_use_lib_paths

Function resolve_use_lib_paths 

pub fn resolve_use_lib_paths(
    use_lib_paths: &[UseLibPath],
    workspace_root: &Path,
    file_dir: Option<&Path>,
) -> Vec<String>
Resolve use lib paths against a workspace root and optional file directory.

  • Absolute paths are accepted only when they stay under workspace_root.
  • $FindBin::Bin-relative paths are resolved against file_dir (or workspace_root if absent).
  • Other relative paths are resolved against workspace_root.