Module token_core

Module token_core 

Shared token model primitives and low-level helpers. Shared primitives for Perl module token parsing and boundary detection.

Structs

ModuleTokenSpan
Byte span for a parsed module token.

Functions

has_standalone_module_token_boundaries
Check if a span from start to end is bounded as a standalone token.
is_module_identifier_char
Check whether ch belongs to Perl module identifier characters.
is_module_token_char
Check whether ch belongs to the module token character class.
parse_module_token
Parse a module token that starts at start in text.