pub fn resolve_use_lib_paths(
use_lib_paths: &[UseLibPath],
workspace_root: &Path,
file_dir: Option<&Path>,
) -> Vec<String>Expand description
Resolve use lib paths against a workspace root and optional file directory.
- Absolute paths are accepted only when they stay under
workspace_root. $FindBin::Bin-relative paths are resolved againstfile_dir(orworkspace_rootif absent).- Other relative paths are resolved against
workspace_root.